@@ -88,7 +88,7 @@ def AgnostigRWKV(ops: module, *args):
                 stated, ddd, self.time_mix_r_ffn[xx])))
 
             x = ops.add(mvv, ops.multiply(
-                ops.matvec(self.value_ffn[xx], km*km), rt))
+                ops.matvec(self.value_ffn[xx], ops.multiply(km, km)), rt))
 
             return x, xy, outb, outc, ddd
 
